@@ -34,10 +34,10 @@ from minos.common import (
 from ..decorators import (
     EnrouteBuilder,
 )
-from ..messages import (
+from ..requests import (
     ResponseException,
 )
-from .messages import (
+from .requests import (
     ScheduledRequest,
 )
 
@@ -186,7 +186,7 @@ class PeriodicTask:
             now = current_datetime()
 
         request = ScheduledRequest(now)
-        logger.info("Running periodic task...")
+        logger.debug("Running periodic task...")
         try:
             self._running = True
             with suppress(asyncio.CancelledError):
